@@ -52,7 +52,8 @@ class ComplexInput(InputLayer, ComplexLayer):
                                            )
 
     def get_real_equivalent(self):
-        return ComplexInput(input_shape=self.input_shape, batch_size=self.batch_size, dtype=self.dtype,
+        real_input_shape = self.input_shape[:-1] + self.input_shape[-1]*2
+        return ComplexInput(input_shape=real_input_shape, batch_size=self.batch_size, dtype=self.dtype,
                             input_tensor=self.input_tensor, sparse=self.sparse, name=f'real_{self.name}',
                             ragged=self.ragged)
 
@@ -217,6 +218,15 @@ class ComplexDropout(Layer, ComplexLayer):
     def get_real_equivalent(self):
         return ComplexDropout(rate=self.rate, seed=self.seed, noise_shape=self.noise_shape)
 
+    def get_config(self):
+        config = {
+            'rate': self.rate,
+            'noise_shape': self.noise_shape,
+            'seed': self.seed
+        }
+        base_config = super(ComplexDropout, self).get_config()
+        return dict(list(base_config.items()) + list(config.items()))
+
 
 class ComplexConv(Layer, ComplexLayer):
     """
@@ -588,8 +598,7 @@ class ComplexConv(Layer, ComplexLayer):
                            kernel_initializer=self.kernel_initializer, bias_initializer=self.bias_initializer,
                            kernel_regularizer=self.kernel_regularizer, bias_regularizer=self.bias_regularizer,
                            activity_regularizer=self.activity_regularizer, kernel_constraint=self.kernel_constraint,
-                           bias_constraint=self.bias_constraint, trainable=self.trainable, name=self.name,
-                           conv_op=self.conv_op)
+                           bias_constraint=self.bias_constraint, trainable=self.trainable, name=self.name+"_real_equiv")
 
 
 class ComplexConv1D(ComplexConv):
@@ -982,7 +991,7 @@ __author__ = 'J. Agustin BARRACHINA'
 __copyright__ = 'Copyright 2020, {project_name}'
 __credits__ = ['{credit_list}']
 __license__ = '{license}'
-__version__ = '1.0.2'
+__version__ = '1.0.4'
 __maintainer__ = 'J. Agustin BARRACHINA'
 __email__ = 'joseagustin.barra@gmail.com; jose-agustin.barrachina@centralesupelec.fr'
 __status__ = '{dev_status}'
